{# Copyright 2022, Red Hat, Inc. #} {# SPDX-License-Identifier: LGPL-2.1-or-later #}

### Advanced filtering options

Filter by result:
Pass Fail Not checked Not applicable Fixed Error Fix failed Fix unsuccessful Informational Unknown
Filter by severity:
high Medium Low Unknown
{%- if debug_setting.button_show_all_rules -%}
{%- endif -%} {%- if debug_setting.button_show_all_rules_and_oval_test_details -%}
{%- endif -%}